@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: paned_notebook.h,v 1.7 2004/01/15 15:05:35 fuyu Exp $
+ * $Id: paned_notebook.h,v 1.8 2004/04/06 18:12:17 fuyu Exp $
  */
 
 #ifndef _PANED_NOTEBOOK_H_
@@ -92,24 +92,34 @@ struct _PanedNotebook
   /* tool_bar */
   GtkWidget *left_arrow;
   GtkWidget *right_arrow;
-  GtkOptionMenu *contents_menu;
 
+#if GTK_MINOR_VERSION <= 2
+  GtkOptionMenu *contents_menu;
   /* contents_menu */
   GtkMenu *contents_list;
 
+  GtkMenuItem *active_menu_item;
+  /* ɽitem(item,view,menu_item,tab_label)ꥹ */
+  GSList *items_shown;
+#else
+  GtkComboBox *contents_menu;
+  GtkListStore *contents_list;
+
+  GtkActionGroup *action_group;
+  GtkUIManager *ui_manager;
+# if 0	/* ̤ */
+  GtkAccelGroup *accel_group;
+# endif
+#endif
+
   /* contents_paneβ */
   ModNotebook *item_contents;
 
-
-  /* item_contentsɽitemΥꥹ */
-  GSList *items_shown;
   int number_of_items_shown;
 
   gpointer current_item;
   GtkWidget *current_item_view;
 
-  GtkMenuItem *active_menu_item;
-
   gboolean position_zero_hack;
 };
 
