@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: response_editor.c,v 1.11 2004/02/28 22:59:25 fuyu Exp $
+ * $Id: response_editor.c,v 1.12 2004/04/06 18:12:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -146,8 +146,13 @@ response_editor_init(ResponseEditor *editor)
   gtk_widget_show(name_label);
   gtk_box_pack_start(editor->hbox, name_label, FALSE, FALSE, 0);
 
+#if GTK_MINOR_VERSION <= 2
   name_combo = gtk_combo_new();
   editor->name_combo = GTK_COMBO(name_combo);
+#else
+  name_combo = gtk_combo_box_entry_new_text();
+  editor->name_combo = GTK_COMBO_BOX(name_combo);
+#endif
   gtk_widget_show(name_combo);
   gtk_box_pack_start(editor->hbox, name_combo, TRUE, TRUE, 0);
 
@@ -155,8 +160,13 @@ response_editor_init(ResponseEditor *editor)
   gtk_widget_show(mail_label);
   gtk_box_pack_start(editor->hbox, mail_label, FALSE, FALSE, 0);
 
+#if GTK_MINOR_VERSION <= 2
   mail_combo = gtk_combo_new();
   editor->mail_combo = GTK_COMBO(mail_combo);
+#else
+  mail_combo = gtk_combo_box_entry_new_text();
+  editor->mail_combo = GTK_COMBO_BOX(mail_combo);
+#endif
   gtk_widget_show(mail_combo);
   gtk_box_pack_start(editor->hbox, mail_combo, TRUE, TRUE, 0);
 
@@ -222,7 +232,11 @@ response_editor_get_name(ResponseEditor *editor)
 {
   g_return_val_if_fail(IS_RESPONSE_EDITOR(editor), NULL);
 
+#if GTK_MINOR_VERSION <= 2
   return gtk_entry_get_text(GTK_ENTRY(editor->name_combo->entry));
+#else
+  return gtk_entry_get_text(GTK_ENTRY(GTK_BIN(editor->name_combo)->child));
+#endif
 }
 
 
@@ -231,7 +245,11 @@ response_editor_set_name(ResponseEditor *editor, const gchar *name)
 {
   g_return_if_fail(IS_RESPONSE_EDITOR(editor));
 
+#if GTK_MINOR_VERSION <= 2
   gtk_entry_set_text(GTK_ENTRY(editor->name_combo->entry), name);
+#else
+  gtk_entry_set_text(GTK_ENTRY(GTK_BIN(editor->name_combo)->child), name);
+#endif
 }
 
 
@@ -248,7 +266,12 @@ response_editor_add_name(ResponseEditor *editor, const gchar *name)
     return;
 
   editor->name_list = g_list_append(editor->name_list, g_strdup(name));
+
+#if GTK_MINOR_VERSION <= 2
   gtk_combo_set_popdown_strings(editor->name_combo, editor->name_list);
+#else
+  gtk_combo_box_append_text(editor->name_combo, name);
+#endif
 }
 
 
@@ -257,7 +280,11 @@ response_editor_get_mail(ResponseEditor *editor)
 {
   g_return_val_if_fail(IS_RESPONSE_EDITOR(editor), NULL);
 
+#if GTK_MINOR_VERSION <= 2
   return gtk_entry_get_text(GTK_ENTRY(editor->mail_combo->entry));
+#else
+  return gtk_entry_get_text(GTK_ENTRY(GTK_BIN(editor->mail_combo)->child));
+#endif
 }
 
 
@@ -266,7 +293,11 @@ response_editor_set_mail(ResponseEditor *editor, const gchar *mail)
 {
   g_return_if_fail(IS_RESPONSE_EDITOR(editor));
 
+#if GTK_MINOR_VERSION <= 2
   gtk_entry_set_text(GTK_ENTRY(editor->mail_combo->entry), mail);
+#else
+  gtk_entry_set_text(GTK_ENTRY(GTK_BIN(editor->mail_combo)->child), mail);
+#endif
 }
 
 
@@ -284,7 +315,11 @@ response_editor_add_mail(ResponseEditor *editor, const gchar *mail)
 
   editor->mail_list = g_list_append(editor->mail_list, g_strdup(mail));
 
+#if GTK_MINOR_VERSION <= 2
   gtk_combo_set_popdown_strings(editor->mail_combo, editor->mail_list);
+#else
+  gtk_combo_box_append_text(editor->mail_combo, mail);
+#endif
 }
 
 
