@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: thread_proxy.c,v 1.9 2004/01/18 04:50:59 fuyu Exp $
+ * $Id: thread_proxy.c,v 1.10 2004/01/30 22:56:08 fuyu Exp $
  */
 
 #include "config.h"
@@ -100,7 +100,8 @@ static gboolean thread_proxy_preview_response(OchushaBBSThread *thread,
 static gboolean thread_proxy_post_supported(OchushaBBSThread *thread);
 static gboolean thread_proxy_post_response(OchushaBBSThread *thread,
 					   OchushaNetworkBroker *broker,
-					   const OchushaBBSResponse *response);
+					   const OchushaBBSResponse *response,
+					   gboolean use_id);
 
 
 GType
@@ -429,14 +430,15 @@ thread_proxy_post_supported(OchushaBBSThread *thread)
 static gboolean
 thread_proxy_post_response(OchushaBBSThread *thread,
 			   OchushaNetworkBroker *broker,
-			   const OchushaBBSResponse *response)
+			   const OchushaBBSResponse *response,
+			   gboolean use_id)
 {
   ThreadProxy *proxy;
   g_return_val_if_fail(IS_THREAD_PROXY(thread), FALSE);
   proxy = THREAD_PROXY(thread);
 
   return ochusha_bbs_thread_post_response(proxy->real_thread,
-					  broker, response);
+					  broker, response, use_id);
 }
 
 
