@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.27 2004/01/27 11:58:11 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.28.2.1 2004/05/01 16:02:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -581,6 +581,113 @@ ochusha_config_cache_unlink_file(const OchushaConfig *config, const char *url)
 }
 
 
+/*
+ * ochusha_config_image_cache_open_file:
+ *
+ * ꤵ줿URLФåե򳫤
+ * flagsopenƥॳͿflagsǤ롣
+ */
+int
+ochusha_config_image_cache_open_file(const OchushaConfig *config,
+				     const char *url, int flags)
+{
+  char *cur_pos;
+  char pathname[PATH_MAX];
+  int len;
+  int result;
+
+  if (url == NULL)
+    return -1;
+
+  if (config->home == NULL)
+    return -1;
+
+  if (url[strlen(url) - 1] == '/')
+    return -1;
+
+  /*
+   * ݤʤΤurlhttp://server/.*ǤȷǤ
+   */
+
+  cur_pos = strstr(url, "http://");
+  if (cur_pos == NULL)
+    return -1;
+
+  len = snprintf(pathname, PATH_MAX, "%s/image/%s", config->home,
+		 url + 7);	/* "http://"ʬά */
+
+  if (len >= PATH_MAX)
+    return -1;
+
+  if ((flags & O_CREAT) == 0)
+    return open(pathname, flags);
+
+  result = open(pathname, flags, 0x180);
+  if (result >= 0)
+    return result;
+
+  while (TRUE)
+    {
+      if (pathname[len] == '/')
+	break;
+      len--;
+    }
+  pathname[len] = '\0';
+
+  if (!mkdir_p(pathname))
+    return -1;
+
+  pathname[len] = '/';
+
+  return open(pathname, flags, 0x180);
+}
+
+
+/*
+ * ochusha_config_image_cache_unlink_file:
+ *
+ * URLбåե뤬¸ߤunlink롣
+ */
+void
+ochusha_config_image_cache_unlink_file(const OchushaConfig *config, const char *url)
+{
+  /*
+   * ݤʤΤurlhttp://server/.*ǤȷǤ
+   */
+  char *cur_pos;
+  char buffer[PATH_MAX];
+  int len;
+  char *pathname;
+
+  if (url == NULL)
+    return;
+
+  if (config->home == NULL)
+    return;
+
+  if (url[strlen(url) - 1] == '/')
+    return;
+
+  cur_pos = strstr(url, "http://");
+  if (cur_pos == NULL)
+    return;
+
+  len = snprintf(buffer, PATH_MAX, "image/%s", url + 7);
+  					       /* "http://"ʬά */
+
+  if (len >= PATH_MAX)
+    return;
+
+  pathname = ochusha_config_find_file(config, buffer, NULL);
+  if (pathname == NULL)
+    return;
+
+  unlink(pathname);
+
+  G_FREE(pathname);
+}
+
+
 gboolean
 ochusha_utils_get_attribute_boolean(GHashTable *hash_table,
 				    const char *attr_name)
@@ -935,7 +1042,7 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
 			 gpointer user_data)
 {
   int fd;
-  gzFile *config_xml;
+  gzFile config_xml;
   const char *empty_string = "";
 
   fd = ochusha_config_open_file(config, OCHUSHA_CONFIG_XML, subdir,
