@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.60 2004/02/26 06:05:10 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.60.2.1 2004/05/01 16:02:58 fuyu Exp $
  */
 
 #include "config.h"
@@ -2081,14 +2081,21 @@ ochusha_network_broker_read_from_url_full(OchushaNetworkBroker *broker,
 
   if (broker->config->offline
       || mode == OCHUSHA_NETWORK_BROKER_CACHE_AS_IS
-      || mode == OCHUSHA_NETWORK_BROKER_CACHE_ONLY)
+      || mode == OCHUSHA_NETWORK_BROKER_CACHE_ONLY
+      || mode == OCHUSHA_NETWORK_BROKER_IMAGE_CACHE)
     {
       /* å夬ä餽򤽤Τޤ޻Ȥ */
       int fd;
       if (buffer != NULL && buffer->length > 0)
 	return buffer;
 
-      fd = ochusha_config_cache_open_file(broker->config, cache_url, O_RDONLY);
+      if (mode == OCHUSHA_NETWORK_BROKER_IMAGE_CACHE)
+	fd = ochusha_config_image_cache_open_file(broker->config,
+						  cache_url, O_RDONLY);
+      else
+	fd = ochusha_config_cache_open_file(broker->config,
+					    cache_url, O_RDONLY);
+	
       if (fd >= 0)
 	{
 	  WorkerJob *job = G_NEW0(WorkerJob, 1);
@@ -2120,26 +2127,7 @@ ochusha_network_broker_read_from_url_full(OchushaNetworkBroker *broker,
 	  return buffer;
 	}
 
-      if (mode == OCHUSHA_NETWORK_BROKER_CACHE_ONLY)
-	{
-	  /* åʤĥå夷Ȥʤ */
-#if 0	/* ƤӽФ¦Թǰ褺ȥ */
-	  ochusha_async_buffer_emit_access_failed(buffer,
-			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_CACHE_NOT_FOUND,
-			_("Couldn't find cache that should exist."));
-#endif
-	  return buffer;
-	}
-
-      if (broker->config->offline)
-	{
-#if 0	/* ƤӽФ¦Թǰ褺ȥ */
-	  ochusha_async_buffer_emit_access_failed(buffer,
-			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_NOT_CONNECTED,
-			_("Network not connected on offline mode."));
-#endif
-	  return buffer;
-	}
+      return buffer;
     }
 
   switch (mode)
