@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.h,v 1.18 2004/02/26 06:05:10 fuyu Exp $
+ * $Id: ochusha_network_broker.h,v 1.18.2.1 2004/05/01 16:02:59 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_NETWORK_BROKER_H_
@@ -61,7 +61,8 @@ typedef enum
   OCHUSHA_NETWORK_BROKER_CACHE_ONLY,
   OCHUSHA_NETWORK_BROKER_CACHE_AS_IS,
   OCHUSHA_NETWORK_BROKER_CACHE_TRY_UPDATE,
-  OCHUSHA_NETWORK_BROKER_CACHE_TRY_REFRESH
+  OCHUSHA_NETWORK_BROKER_CACHE_TRY_REFRESH,
+  OCHUSHA_NETWORK_BROKER_IMAGE_CACHE
 } OchushaNetworkBrokerCacheMode;
 
 
