@@ -2,7 +2,7 @@
 
   regparse.h -  Oniguruma (regular expression library)
 
-  Copyright (C) 2003  K.Kosako (kosako@sofnec.co.jp)
+  Copyright (C) 2003-2004  K.Kosako (kosako@sofnec.co.jp)
 
 **********************************************************************/
 #ifndef REGPARSE_H
@@ -75,6 +75,12 @@
 
 #define CCLASS_SET_NOT(cc)      (cc)->not = 1
 
+#define NQ_TARGET_ISNOT_EMPTY     0
+#define NQ_TARGET_IS_EMPTY        1
+#define NQ_TARGET_IS_EMPTY_MEM    2
+#define NQ_TARGET_IS_EMPTY_REC    3
+
+
 typedef struct {
   UChar* s;
   UChar* end;
@@ -95,7 +101,7 @@ typedef struct {
   int upper;
   int greedy;
   int by_number;         /* {n,m} */
-  int target_may_empty;  /* target can match with empty data */
+  int target_empty_info;
   struct _Node* head_exact;
   struct _Node* next_head_exact;
   int is_refered;     /* include called node. don't eliminate even if {0} */
@@ -139,12 +145,12 @@ typedef struct {
   int state;
   int type;
   int regnum;
-  RegOptionType option;
+  OnigOptionType option;
   struct _Node* target;
   AbsAddrType call_addr;
   /* for multiple call reference */
-  RegDistance min_len; /* min length (byte) */
-  RegDistance max_len; /* max length (byte) */ 
+  OnigDistance min_len; /* min length (byte) */
+  OnigDistance max_len; /* max length (byte) */ 
   int char_len;        /* character length  */
   int opt_count;       /* referenced count in optimize_node_left() */
 } EffectNode;
@@ -218,9 +224,9 @@ typedef struct _Node {
     (senv)->mem_nodes_dynamic : (senv)->mem_nodes_static)
 
 typedef struct {
-  RegOptionType   option;
-  RegCharEncoding enc;
-  RegSyntaxType*  syntax;
+  OnigOptionType   option;
+  OnigEncoding enc;
+  OnigSyntaxType*  syntax;
   BitStatusType   capture_history;
   BitStatusType   bt_mem_start;
   BitStatusType   bt_mem_end;
@@ -248,23 +254,23 @@ typedef struct {
 #define IS_SYNTAX_OP2(syn, opm)   (((syn)->op2 & (opm)) != 0)
 #define IS_SYNTAX_BV(syn, bvm)    (((syn)->behavior & (bvm)) != 0)
 
-extern int    regex_is_code_in_cc P_((RegCharEncoding enc, CodePoint code, CClassNode* cc));
-extern int    regex_strncmp P_((UChar* s1, UChar* s2, int n));
-extern void   regex_scan_env_set_error_string P_((ScanEnv* env, int ecode, UChar* arg, UChar* arg_end));
-extern int    regex_scan_unsigned_number P_((UChar** src, UChar* end, RegCharEncoding enc));
-extern void   regex_reduce_nested_qualifier P_((Node* pnode, Node* cnode));
-extern void   regex_node_conv_to_str_node P_((Node* node, int raw));
-extern int    regex_node_str_cat P_((Node* node, UChar* s, UChar* end));
-extern void   regex_node_free P_((Node* node));
-extern Node*  regex_node_new_effect P_((int type));
-extern Node*  regex_node_new_anchor P_((int type));
-extern int    regex_free_node_list();
-extern int    regex_names_free P_((regex_t* reg));
-extern int    regex_parse_make_tree P_((Node** root, UChar* pattern, UChar* end, regex_t* reg, ScanEnv* env));
+extern int    onig_is_code_in_cc P_((OnigEncoding enc, OnigCodePoint code, CClassNode* cc));
+extern int    onig_strncmp P_((UChar* s1, UChar* s2, int n));
+extern void   onig_scan_env_set_error_string P_((ScanEnv* env, int ecode, UChar* arg, UChar* arg_end));
+extern int    onig_scan_unsigned_number P_((UChar** src, UChar* end, OnigEncoding enc));
+extern void   onig_reduce_nested_qualifier P_((Node* pnode, Node* cnode));
+extern void   onig_node_conv_to_str_node P_((Node* node, int raw));
+extern int    onig_node_str_cat P_((Node* node, UChar* s, UChar* end));
+extern void   onig_node_free P_((Node* node));
+extern Node*  onig_node_new_effect P_((int type));
+extern Node*  onig_node_new_anchor P_((int type));
+extern int    onig_free_node_list();
+extern int    onig_names_free P_((regex_t* reg));
+extern int    onig_parse_make_tree P_((Node** root, UChar* pattern, UChar* end, regex_t* reg, ScanEnv* env));
 
-#ifdef REG_DEBUG
+#ifdef ONIG_DEBUG
 #ifdef USE_NAMED_GROUP
-extern int regex_print_names(FILE*, regex_t*);
+extern int onig_print_names(FILE*, regex_t*);
 #endif
 #endif
 
